var assign = require('object-assign');
var AppConstants = require('../constants/AppConstants');
var AppDispatcher = require('../dispatchers/AppDispatcher');
var EventEmitter = require('events').EventEmitter;
var Session = require('./Session');

var DEPOTS_LISTED = 'depots_listed';
var DIR_LISTED = 'dir_listed';

// Our files store is primarily used to fetch path information about the depot
// tree.
var Files = assign({}, EventEmitter.prototype, {

  listDepots: function() {
    var client = Session.getClient();
    var ajax = client.listFiles();

    var self = this;

    ajax.done(function(depots) {
      self.emitDepotsListed(depots);
    });
  },

  /**
   * Create a file list for the indicated directory Path.
   *
   * @param {string} dir A path string
   */
  listDir: function(dir) {
    var client = Session.getClient();
    var ajax = client.listFiles(dir);

    var self = this;

    ajax.done(function(items) {
      self.emitDirListed(dir, items);
    });
  },

  emitDepotsListed: function(depots) {
    this.emit(DEPOTS_LISTED, depots);
  },

  addDepotsListedListener: function(callback) {
    this.on(DEPOTS_LISTED, callback);
  },

  removeDepotsListedListener: function(callback) {
    this.removeListener(DEPOTS_LISTED, callback);
  },

  emitDirListed: function(dir, items) {
    this.emit(DIR_LISTED, dir, items);
  },

  addDirListedListener: function(callback) {
    this.on(DIR_LISTED, callback);
  },

  removeDirListedListener: function(callback) {
    this.removeListener(DIR_LISTED, callback);
  }
});

AppDispatcher.register(function(action) {
  switch(action.actionType) {
    case AppConstants.LIST_DEPOTS:
      Files.listDepots();
      break;

    case AppConstants.LIST_DIR:
      Files.listDir(action.dir);
      break;

    default:
      // Do nothing
  }
});

module.exports = Files;
