// The Location store keeps a single 'location' reference available that
// has a few different structures:
//
// 1. The project list:
//
//     { projectList: 'my' }
//     { projectList: 'all' }
//
// 2. A project details:
//
//     { project: 'ID' }
//
// 3. Create a project:
//
//     { createProject: true }

var AppConstants = require('../constants/AppConstants');
var AppDispatcher = require('../dispatchers/AppDispatcher');
var EventEmitter = require('events').EventEmitter;
var assign = require('object-assign');

// Events
var NEW_LOCATION = 'new_location';

// Default values
var DEFAULT_LOCATION = { projectList: "my" };

var Location = assign({}, EventEmitter.prototype, {

  getLocation: function() {
    var location = sessionStorage.getItem('location');
    if (!location) {
      location = DEFAULT_LOCATION;
    } else {
      location = JSON.parse(location);
    }
    return location;
  },

  setLocation: function(location) {
    sessionStorage.setItem('location', JSON.stringify(location));
    // If we change the location as the result of another action (very common
    // to do after, say, we handle success of a project) we need to dispatch
    // the event outside of this dispatcher thread.
    var self = this;
    setTimeout(function() {
      self.emitNewLocation();
    });
  },

  emitNewLocation: function() {
    this.emit(NEW_LOCATION);
  },

  addNewLocationListener: function(callback) {
    this.on(NEW_LOCATION, callback);
  },

  removeNewLocationListener: function(callback) {
    this.removeListener(NEW_LOCATION, callback);
  }
});

AppDispatcher.register(function(action) {
  switch(action.actionType) {
    case AppConstants.CHANGE_LOCATION:
      Location.setLocation(action.location);
      break;

    default:
      // Do nothing
  }
});

module.exports = Location;
